==> free-sa-1.4.0.tar.gz: free-sa-1.4.0/src/reports/r_topuser.c <==
#include "global.h"


int ccueCount = 0;


void ReportTopUser(void) {
    FILE *TUR;
    short int i;
    char stext[128];

    /* TUR: open & header */
    SAsnprintf(stext, sizeof(stext), "%s (%s)", loc->Bytes, loc->Desc);
    TUR = SAfopenH("../", 'r', loc->TopUser, stext, 1, "w", TEMPL_REPORT, icfg.ReportDir, icfg.TURname);
    
    /* TUR: write table header */
    SAfprintf(TUR, "\t<tr><td class=el>\n\t<tr><th>%s%s<th>%s<th>%s<th>%s<th>%%%s\n", 
	      loc->No, (cfg.UR) ? "<th>" : "", loc->User, loc->Connections, loc->Bytes, loc->Bytes);
    
    /* TUR: sort by bytes (reverse) */
    qsort(Users, (size_t)icfg.ueCount, sizeof(struct SAentry), (int (*)(const void *, const void *))rcompSAentryB);

    /* TUR: write user stats */
    for (i = 0; i < icfg.ueCount; i++) {
	if (Users[i].count) {
	    SAfprintf(TUR, "<tr><td>%d", i + 1);
	    if (cfg.UR) SAfprintf(TUR, "\
<td><a href=\"g_%s.html\"><img src=\"../g.png\" alt=\"\"></a>&nbsp;<a href=\"d_%s.html\"><img src=\"../d.png\" alt=\"\"></a>\
<td class=lt><a href=\"u%s.html\">%s</a>", Users[i].name, Users[i].name, Users[i].name, Users[i].vname);
	    else SAfprintf(TUR, "<td class=lt>%s", Users[i].vname);
	    SAfprintf(TUR, "<td>%'d<td>%s<td>%.2f", Users[i].count, icfg.SAB(Users[i].Bytes), Users[i].Bytes / ccBytes * 100);
	    IndicsByIndex(TUR, i);

	    /* ER: compute maximum vname */
	    if (cfg.ER != NULL) maxvname = SAmax(maxvname, strlen(Users[i].vname));
	    ccueCount++;
	}
    }
    
    /* TUR: write total stats */
    SAfwrite1("<tr><td class=el>", 17L, TUR);
    if (cfg.UR) SAfprintf(TUR, "<td><a href=\"g_%s.html\"><img src=\"../g.png\" alt=\"\"></a>&nbsp;<a href=\"d_%s.html\"><img src=\"../d.png\" alt=\"\"></a>", icfg.TTLname, icfg.TTLname);
    SAfprintf(TUR, "<th class=lt>%s<th class=rt>%'d<th class=rt>%s<th class=rt>%.2f\n", loc->TOTAL, ccCount, icfg.SAB(ccBytes), 100.0);
    /* TUR: write average stats */
    SAfwrite1("<tr><td class=el>", 17L, TUR);
    if (cfg.UR) SAfprintf(TUR, "<td><a href=\"g_%s.html\"><img src=\"../g.png\" alt=\"\"></a>&nbsp;<a href=\"d_%s.html\"><img src=\"../d.png\" alt=\"\"></a>", icfg.AVGname, icfg.AVGname);
    SAfprintf(TUR, "<th class=lt>%s<th class=rt>%'d<th class=rt>%s<th class=rt>%.2f\n", loc->AVERAGE, ccCount / ccueCount, icfg.SAB(ccBytes / ccueCount), 100.0 / ccueCount);

    /* TUR: close */
    SAfcloseH(TUR, icfg.TURname);
}

==> free-sa-1.4.3.tar.gz: free-sa-1.4.3/src/reports/r_topuser.c <==
#include "global.h"


int ccueCount = 0;


void ReportTopUser(void) {
    FILE *TUR;
    short int i;
    char stext[128];

    /* TUR: open & header */
    SAsnprintf(stext, sizeof(stext), "%s (%s)", loc->Bytes, loc->Desc);
    TUR = SAfopenH("../", 'r', loc->TopUser, stext, 1, "w", TEMPL_REPORT, icfg.ReportDir, icfg.TURname);
    
    /* TUR: write table header */
    SAfprintf(TUR, "\t<tr><td class=el>\n\t<tr><th>%s%s<th>%s<th>%s<th>%s<th>%%%s\n", 
	      loc->No, (cfg.UR) ? "<th>" : "", loc->User, loc->Connections, loc->Bytes, loc->Bytes);
    
    /* TUR: sort by bytes (reverse) */
    qsort(Users, (size_t)icfg.ueCount, sizeof(struct SAentry), (int (*)(const void *, const void *))rcompSAentryB);

    /* TUR: write user stats */
    for (i = 0; i < icfg.ueCount; i++) {
	if (Users[i].count) {
	    SAfprintf(TUR, "<tr><td>%d", i + 1);
	    if (cfg.UR) SAfprintf(TUR, "\
<td><a href=\"g_%s.html\"><img src=\"../g.png\" alt=\"\"></a>&nbsp;<a href=\"d_%s.html\"><img src=\"../d.png\" alt=\"\"></a>\
<td class=lt><a href=\"u%s.html\">%s</a>", Users[i].name, Users[i].name, Users[i].name, Users[i].vname);
	    else SAfprintf(TUR, "<td class=lt>%s", Users[i].vname);
	    SAfprintf(TUR, "<td>%'d<td>%s<td>%.2f", Users[i].count, icfg.SAB(Users[i].Bytes), Users[i].Bytes / ccBytes * 100);
	    IndicsByIndex(TUR, i);

	    /* ER: compute maximum vname */
	    if (cfg.ER != NULL) maxvname = SAmax(maxvname, strlen(Users[i].vname));
	    ccueCount++;
	}
    }
    
    /* TUR: write total stats */
    SAfwrite1("<tr><td class=el>", 17L, TUR);
    if (cfg.UR) SAfprintf(TUR, "<th><a href=\"g_%s.html\"><img src=\"../g.png\" alt=\"\"></a>&nbsp;<a href=\"d_%s.html\"><img src=\"../d.png\" alt=\"\"></a>", icfg.TTLname, icfg.TTLname);
    SAfprintf(TUR, "<th class=lt>%s<th class=rt>%'d<th class=rt>%s<th class=rt>%.2f\n", loc->TOTAL, ccCount, icfg.SAB(ccBytes), 100.0);
    /* TUR: write average stats */
    SAfwrite1("<tr><td class=el>", 17L, TUR);
    if (cfg.UR) SAfprintf(TUR, "<th><a href=\"g_%s.html\"><img src=\"../g.png\" alt=\"\"></a>&nbsp;<a href=\"d_%s.html\"><img src=\"../d.png\" alt=\"\"></a>", icfg.AVGname, icfg.AVGname);
    SAfprintf(TUR, "<th class=lt>%s<th class=rt>%'d<th class=rt>%s<th class=rt>%.2f\n", loc->AVERAGE, ccCount / ccueCount, icfg.SAB(ccBytes / ccueCount), 100.0 / ccueCount);

    /* TUR: close */
    SAfcloseH(TUR, icfg.TURname);
}
